@@ -15,9 +15,15 @@ if [[ ${KOLLA_INSTALL_TYPE} == "source" ]] && [[ ! -f ${SITE_PACKAGES}/openstack
         ${SITE_PACKAGES}/openstack_dashboard/local/local_settings.py
 fi
 
-if [[ -f /etc/openstack-dashboard/custom_local_settings ]] && [[ ! -f ${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py ]]; then
-    ln -s /etc/openstack-dashboard/custom_local_settings \
-        ${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py
+if [[ -f /etc/openstack-dashboard/custom_local_settings ]]; then
+    CUSTOM_SETTINGS_FILE="${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py"
+    if  [[ ${KOLLA_INSTALL_TYPE} == "binary" ]] && [[ "${KOLLA_BASE_DISTRO}" =~ ubuntu ]]; then
+        CUSTOM_SETTINGS_FILE="/usr/share/openstack-dashboard/openstack_dashboard/local/custom_local_settings.py"
+    fi
+
+    if [[ ! -L ${CUSTOM_SETTINGS_FILE} ]]; then
+        ln -s /etc/openstack-dashboard/custom_local_settings ${CUSTOM_SETTINGS_FILE}
+    fi
 fi
 
 # Bootstrap and exit if KOLLA_BOOTSTRAP variable is set. This catches all cases
@@ -47,6 +53,14 @@ function config_dashboard {
     fi
 }
 
+function config_blazar_dashboard {
+    for file in ${SITE_PACKAGES}/blazar_dashboard/enabled/_*[^__].py; do
+        config_dashboard "${ENABLE_BLAZAR}" \
+            "${SITE_PACKAGES}/blazar_dashboard/enabled/${file##*/}" \
+            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
+    done
+}
+
 function config_cloudkitty_dashboard {
     for file in ${SITE_PACKAGES}/cloudkittydashboard/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_CLOUDKITTY}" \
@@ -55,6 +69,14 @@ function config_cloudkitty_dashboard {
     done
 }
 
+function config_congress_dashboard {
+    for file in ${SITE_PACKAGES}/congress_dashboard/enabled/_*[^__].py; do
+        config_dashboard "${ENABLE_CONGRESS}" \
+            "${SITE_PACKAGES}/congress_dashboard/enabled/${file##*/}" \
+            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
+    done
+}
+
 function config_designate_dashboard {
     for file in ${SITE_PACKAGES}/designatedashboard/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_DESIGNATE}" \
@@ -146,6 +168,12 @@ function config_neutron_lbaas {
         "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_1481_project_ng_loadbalancersv2_panel.py"
 }
 
+function config_neutron_vpnaas_dashboard {
+    config_dashboard "${ENABLE_NEUTRON_VPNAAS}" \
+        "${SITE_PACKAGES}/neutron_vpnaas_dashboard/enabled/_7100_project_vpn_panel.py" \
+        "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_7100_project_vpn_panel.py"
+}
+
 function config_octavia_dashboard {
     config_dashboard "${ENABLE_OCTAVIA}" \
         "${SITE_PACKAGES}/octavia_dashboard/enabled/_1482_project_load_balancer_panel.py" \
@@ -248,22 +276,31 @@ function config_zun_dashboard {
     done
 }
 
-# NOTE(jeffrey4l, niedbalski): The local_settings and custom_local_settings files
-# affect django-compress behavior, so re-generate the compressed
-# javascript and css if any of those setting files changed
+# Regenerate the compressed javascript and css if any configuration files have
+# changed.  Use a static modification date when generating the tarball
+# so that we only trigger on content changes.
+function settings_bundle {
+    tar -cf- --mtime=1970-01-01 \
+        /etc/openstack-dashboard/local_settings \
+        /etc/openstack-dashboard/custom_local_settings \
+        /etc/openstack-dashboard/local_settings.d 2> /dev/null
+}
+
 function settings_changed {
-    declare -A settings=( ['/etc/openstack-dashboard/local_settings']="/var/lib/kolla/.local_settings.md5sum.txt" ['/etc/openstack-dashboard/custom_local_settings']="/var/lib/kolla/.custom_local_settings.md5sum.txt")
-    declare -x changed=1
-    for path in "${!settings[@]}"; do
-        if [[ ! -f ${settings[$path]} || $(md5sum -c --status ${settings[$path]};echo $?) != 0 || ${FORCE_GENERATE} == "yes" ]]; then
-            changed=0
-            md5sum ${path} > ${settings[$path]}
-        fi
-    done
+    changed=1
+    hash_path=/var/lib/kolla/.settings.md5sum.txt
+
+    if [[ ! -f $hash_path  ]] || ! settings_bundle | md5sum -c --status $hash_path || [[ $FORCE_GENERATE == yes ]]; then
+        changed=0
+        settings_bundle | md5sum > $hash_path
+    fi
+
     return ${changed}
 }
 
+config_blazar_dashboard
 config_cloudkitty_dashboard
+config_congress_dashboard
 config_designate_dashboard
 config_fwaas_dashboard
 config_freezer_ui
@@ -275,6 +312,7 @@ config_manila_ui
 config_mistral_dashboard
 config_murano_dashboard
 config_neutron_lbaas
+config_neutron_vpnaas_dashboard
 config_octavia_dashboard
 config_sahara_dashboard
 config_searchlight_ui
