@@ -16,19 +16,7 @@ function bootstrap_db {
             exit 1
         fi
     done
-# NOTE(sbezverk): Currently kolla-kubernetes does not use Galera and disables wsrep driver.
-# This check will run only for non kolla-kubernetes bootstrap deployments.
-    if [[ ! "${!KOLLA_KUBERNETES[@]}" ]]; then
-        TIMEOUT=${DB_MAX_TIMEOUT:-60}
-        while [ $(mysql -u root -e "SHOW STATUS LIKE 'wsrep_ready'" | tail -n 1 | cut -f 2) != "ON" ]; do
-            if [[ ${TIMEOUT} -gt 0 ]]; then
-                let TIMEOUT-=1
-                sleep 1
-            else
-                exit 1
-            fi
-        done
-    fi
+
     sudo -E kolla_security_reset
     mysql -u root --password="${DB_ROOT_PASSWORD}" -e "GRANT ALL PRIVILEGES ON *.* TO 'root'@'localhost' IDENTIFIED BY '${DB_ROOT_PASSWORD}' WITH GRANT OPTION;"
     mysql -u root --password="${DB_ROOT_PASSWORD}" -e "GRANT ALL PRIVILEGES ON *.* TO 'root'@'%' IDENTIFIED BY '${DB_ROOT_PASSWORD}' WITH GRANT OPTION;"
@@ -50,6 +38,19 @@ if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
     exit 0
 fi
 
+# This catches all cases of the KOLLA_UPGRADE variable being set, including empty
+if [[ "${!KOLLA_UPGRADE[@]}" ]]; then
+    # The mysql_upgrade command treats any directories under /var/lib/mysql as
+    # databases. Somehow we can end up with a .pki directory, which causes the
+    # command to fail with this error:
+    # Incorrect database name '#mysql50#.pki' when selecting the database
+    # There doesn't seem to be anything in the directory, so remove it.
+    rm -rf /var/lib/mysql/.pki
+
+    mysql_upgrade --user=root --password="${DB_ROOT_PASSWORD}"
+    exit 0
+fi
+
 if [[ "${!BOOTSTRAP_ARGS[@]}" ]]; then
     ARGS="${BOOTSTRAP_ARGS}"
 fi
